# Release notes for MUSE v1.3.3 (February 7, 2025)

These are the main changes in MUSE v1.3.3.

## Bug fixes

### Fixed an error with the LCOE and EAC outputs ({github}`657`)

- Data in these outputs was previously shown for the wrong year (e.g. LCOE values for 2025 shown as 2020). This is now fixed.

### Fixed errors in the calculation of commodity supply ({github}`585`)

- Particularly in relation to multi-region models, and technologies with multiple end-use commodities

## Deprecated features

### Dropped the `foresight` and `forecast` parameters ({github}`641` and {github}`645`)

These parameters previously allowed agents to forecast beyond the investment year, but this feature has been dropped since [v1.3.0](https://muse-os.readthedocs.io/en/latest/release-notes/v1.3.0.html#agent-forecasting-beyond-the-time-interval). Users are advised to remove these parameters from their settings files, otherwise a warning will be raised.

## Optimization

Several changes aimed at improving performance and simplifying the codebase for ease of maintenance. See {github}`647`, {github}`641`, {github}`650`, {github}`642`, {github}`645`. Some of these changes may also have a subtle effect on results.
